@@ -66,6 +66,11 @@ pub fn parse_region(region: &str) -> Region {
         .map_or(format!("{}:{}-{}", name, st + 1, en), |m| {
             m.as_str().to_string()
         });
+
+    if st > en {
+        panic!("Region start must be less than end.\n{}", region);
+    }
+
     Region { name, st, en, id }
 }
 
@@ -94,6 +99,11 @@ pub fn parse_bed_rec(region: &str) -> Region {
         .map_or(format!("{}:{}-{}", name, st + 1, en), |m| {
             m.as_str().to_string()
         });
+
+    if st > en {
+        panic!("Region start must be less than end.\n{}", region);
+    }
+
     Region { name, st, en, id }
 }
 
@@ -111,7 +121,7 @@ pub fn parse_bed(filename: &str) -> Vec<Region> {
     for (idx, line) in reader.lines().enumerate() {
         eprint!("\rReading bed line: {}", idx + 1);
         let line = line.unwrap(); // Ignore errors.
-        if line.chars().nth(0).unwrap_or('#') == '#' {
+        if line.chars().next().unwrap_or('#') == '#' {
             continue;
         }
         vec.push(parse_bed_rec(&line));
